@@ -1,7 +1,7 @@
+from calendar import timegm
 import datetime as dt
 from itertools import islice
-from collections import OrderedDict, MutableSet
-from collections.abc import Iterable
+from collections import MutableSet, OrderedDict
 from threading import local
 from tzlocal import get_localzone
 from pytz import timezone, country_timezones, all_timezones, FixedOffset, utc, NonExistentTimeError, common_timezones
@@ -44,7 +44,7 @@ DEFAULT_FORMATS = ISO_8601 + ISO_8601_T + RFC_2822
 
 
 
-# Various utilities to work around oddities (bugs?) in pytz.
+# Various utilities to work around oddities (bugs?) in pytz and python versions.
 
 
 def reapply_tzinfo(datetime, is_dst):
@@ -139,6 +139,18 @@ def tzinfo_localize(tzinfo, datetime, is_dst):
         return tzinfo.localize(datetime)
 
 
+def datetime_timestamp(datetime):
+    '''
+    Equivalent to datetime.timestamp() for pre-3.3
+    '''
+    try:
+        return datetime.timestamp()
+    except AttributeError:
+        utc_datetime = datetime.astimezone(utc)
+        return timegm(utc_datetime.timetuple()) + utc_datetime.microsecond / 1e6
+
+
+
 # Utilities to help with argument handling and the like.
 
 
@@ -154,7 +166,8 @@ def always_tuple(value, convert_None=True):
     '''
     if not convert_None and value is None:
         return value
-    elif isinstance(value, Iterable) and not isinstance(value, str):
+    # elif isinstance(value, Iterable) and not isinstance(value, str):
+    elif hasattr(value, '__iter__') and not isinstance(value, str):
         return tuple(value)
     else:
         return (value,)
@@ -683,11 +696,13 @@ class PyTzFactory(DebugLog):
         for tz in timezones:
 
             if tz is None:
-                yield from check('Locale', get_localzone())
+                # yield from check('Locale', get_localzone())
+                for tzinfo in check('Locale', get_localzone()): yield tzinfo
                 continue
 
             if isinstance(tz, dt.tzinfo):
-                yield from check('Direct', tz)
+                # yield from check('Direct', tz)
+                for tzinfo in check('Direct', tz): yield tzinfo
                 continue
 
             if isinstance(tz, dt.timedelta):
@@ -700,12 +715,14 @@ class PyTzFactory(DebugLog):
 
             if isinstance(tz, int) or isinstance(tz, float):
                 log('Assuming {0} is minutes', tz)
-                yield from check('Fixed offset', FixedOffset(tz))
+                # yield from check('Fixed offset', FixedOffset(tz))
+                for tzinfo in check('Fixed offset', FixedOffset(tz)): yield tzinfo
                 continue
 
             if isinstance(tz, str):
                 try:
-                    yield from check('Name', timezone(tz))
+                    # yield from check('Name', timezone(tz))
+                    for tzinfo in check('Name', timezone(tz)): yield tzinfo
                     # continue to next stage if GMT, EST or similar
                     if datetime is None or '/' in tz:
                         continue
@@ -744,7 +761,8 @@ class PyTzFactory(DebugLog):
             log('Have country code {0}', country)
             zones = country_timezones[country]
             log('Country code {0} has {1} timezones', country, len(zones))
-            yield from map(timezone, zones)
+            # yield from map(timezone, zones)
+            for tzinfo in map(timezone, zones): yield tzinfo
             count += len(zones)
         log('Expanded country codes to {0} timezones', count)
 
@@ -899,7 +917,8 @@ class DateTimeWrapper:
 
     @property
     def timestamp(self):
-        return self.__datetime.timestamp()
+        # return self.__datetime.timestamp()
+        return datetime_timestamp(self.__datetime)
 
     @property
     def tzinfo(self):
